@@ -2,10 +2,15 @@
 from PyObjCTools.TestSupport import *
 from WebKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestDOMEventException (TestCase):
     def testConstants(self):
-        self.failUnlessIsInstance(DOMEventException, unicode)
-        self.failUnlessEqual(DOM_UNSPECIFIED_EVENT_TYPE_ERR, 0)
+        self.assertIsInstance(DOMEventException, unicode)
+        self.assertEqual(DOM_UNSPECIFIED_EVENT_TYPE_ERR, 0)
 
 if __name__ == "__main__":
     main()
