@@ -4,8 +4,8 @@ from WebKit import *
 
 class TestDOMHTMLDListElement (TestCase):
     def testMethods(self):
-        self.failUnlessResultIsBOOL(DOMHTMLDListElement.compact)
-        self.failUnlessArgIsBOOL(DOMHTMLDListElement.setCompact_, 0)
+        self.assertResultIsBOOL(DOMHTMLDListElement.compact)
+        self.assertArgIsBOOL(DOMHTMLDListElement.setCompact_, 0)
 
 if __name__ == "__main__":
     main()
