@@ -4,7 +4,7 @@ from PyObjCTools.TestSupport import *
 
 class TestDOMHTMLTextAreaElement (TestCase):
     def testMehods(self):
-        self.failUnlessResultIsBOOL(DOMHTMLTextAreaElement.willValidate)
+        self.assertResultIsBOOL(DOMHTMLTextAreaElement.willValidate)
 
 if __name__ == "__main__":
     main()
